@@ -15,9 +15,8 @@
 from newrelic.config import (
         initialize as __initialize,
         extra_settings as __extra_settings)
-from newrelic.core.config import (
-        global_settings as __global_settings,
-        ignore_status_code as __ignore_status_code)
+
+from newrelic.core.config import global_settings as __global_settings
 
 from newrelic.core.agent import (
         shutdown_agent as __shutdown_agent,
@@ -38,7 +37,8 @@ from newrelic.api.time_trace import (
         current_trace as __current_trace,
         get_linking_metadata as __get_linking_metadata,
         add_custom_span_attribute as __add_custom_span_attribute,
-        record_exception as __record_exception)
+        record_exception as __record_exception,
+        notice_error as __notice_error)
 
 from newrelic.api.transaction import (
         current_transaction as __current_transaction,
@@ -199,8 +199,6 @@ extra_settings = __wrap_api_call(__extra_settings,
         'extra_settings')
 global_settings = __wrap_api_call(__global_settings,
         'global_settings')
-ignore_status_code = __wrap_api_call(__ignore_status_code,
-        'ignore_status_code')
 shutdown_agent = __wrap_api_call(__shutdown_agent,
         'shutdown_agent')
 register_data_source = __wrap_api_call(__register_data_source,
@@ -242,6 +240,8 @@ add_framework_info = __wrap_api_call(__add_framework_info,
         'add_framework_info')
 record_exception = __wrap_api_call(__record_exception,
         'record_exception')
+notice_error = __wrap_api_call(__notice_error,
+        'notice_error')
 get_browser_timing_header = __wrap_api_call(__get_browser_timing_header,
         'get_browser_timing_header')
 get_browser_timing_footer = __wrap_api_call(__get_browser_timing_footer,
