@@ -18,9 +18,14 @@ import time
 import sys
 import newrelic.packages.six as six
 import traceback
+import warnings
+
+from newrelic.common.object_names import parse_exc_info
+from newrelic.core.config import is_expected_error, should_ignore_error
 from newrelic.core.trace_cache import trace_cache
 from newrelic.core.attribute import (
         process_user_attribute, MAX_NUM_USER_ATTRIBUTES)
+
 from newrelic.api.settings import STRIP_EXCEPTION_MESSAGE
 
 _logger = logging.getLogger(__name__)
@@ -62,6 +67,13 @@ class TimeTrace(object):
     def _is_leaf(self):
         return self.child_count == len(self.children)
 
+    def __str__(self):
+        name = getattr(self, "name", None)
+        return "<id:%d name:%s __str__:%s>" % (id(self), name, super(TimeTrace, self).__str__())
+
+    def __repr__(self):
+        return str(self)
+
     def __enter__(self):
         self.parent = parent = self.parent or current_trace()
         if not parent:
@@ -188,7 +200,7 @@ class TimeTrace(object):
 
         self.user_attributes[key] = value
 
-    def _observe_exception(self, exc_info=None, ignore_errors=[]):
+    def _observe_exception(self, exc_info=None, ignore=None, expected=None, status_code=None):
         # Bail out if the transaction is not active or
         # collection of errors not enabled.
 
@@ -211,91 +223,96 @@ class TimeTrace(object):
 
         # If no exception details provided, use current exception.
 
-        if exc_info and None not in exc_info:
-            exc, value, tb = exc_info
-        else:
-            exc, value, tb = sys.exc_info()
+        # Pull from sys.exc_info if no exception is passed
+        if not exc_info or None in exc_info:
+            exc_info = sys.exc_info()
 
-        # Has to be an error to be logged.
-
-        if exc is None or value is None or tb is None:
+        # If no exception to report, exit
+        if not exc_info or None in exc_info:
             return
 
-        # Where ignore_errors is a callable it should return a
-        # tri-state variable with the following behavior.
-        #
-        #   True - Ignore the error.
-        #   False- Record the error.
-        #   None - Use the default ignore rules.
+        exc, value, tb = exc_info
 
-        should_ignore = None
-
-        if hasattr(transaction, '_ignore_errors'):
-            should_ignore = transaction._ignore_errors(exc, value, tb)
-            if should_ignore:
-                return
-
-        if callable(ignore_errors):
-            should_ignore = ignore_errors(exc, value, tb)
-            if should_ignore:
-                return
-
-        module = value.__class__.__module__
-        name = value.__class__.__name__
-
-        if should_ignore is None:
-            # We need to check for module.name and module:name.
-            # Originally we used module.class but that was
-            # inconsistent with everything else which used
-            # module:name. So changed to use ':' as separator, but
-            # for backward compatibility need to support '.' as
-            # separator for time being. Check that with the ':'
-            # last as we will use that name as the exception type.
-
-            if module:
-                names = ('%s:%s' % (module, name), '%s.%s' % (module, name))
-            else:
-                names = (name)
-
-            for fullname in names:
-                if not callable(ignore_errors) and fullname in ignore_errors:
-                    return
-
-                if fullname in settings.error_collector.ignore_errors:
-                    return
-
-            fullname = names[0]
-
-        else:
-            if module:
-                fullname = '%s:%s' % (module, name)
-            else:
-                fullname = name
+        module, name, fullnames, message = parse_exc_info((exc, value, tb))
+        fullname = fullnames[0]
 
         # Check to see if we need to strip the message before recording it.
 
         if (settings.strip_exception_messages.enabled and
                 fullname not in settings.strip_exception_messages.whitelist):
             message = STRIP_EXCEPTION_MESSAGE
-        else:
-            try:
 
-                # Favor unicode in exception messages.
+        # Where expected or ignore are a callable they should return a
+        # tri-state variable with the following behavior.
+        #
+        #   True - Ignore the error.
+        #   False- Record the error.
+        #   None - Use the default rules.
 
-                message = six.text_type(value)
+        # Precedence: 
+        # 1. function parameter override as bool
+        # 2. function parameter callable
+        # 3. callable on transaction
+        # 4. function parameter iterable of class names
+        # 5. default rule matching from settings
 
-            except Exception:
-                try:
+        should_ignore = None
+        is_expected = None
 
-                    # If exception cannot be represented in unicode, this means
-                    # that it is a byte string encoded with an encoding
-                    # that is not compatible with the default system encoding.
-                    # So, just pass this byte string along.
+        # Check against ignore rules
+        # Boolean parameter (True/False only, not None)
+        if isinstance(ignore, bool):
+            should_ignore = ignore
+            if should_ignore:
+                return
 
-                    message = str(value)
+        # Callable parameter
+        if should_ignore is None and callable(ignore):
+            should_ignore = ignore(exc, value, tb)
+            if should_ignore:
+                return
 
-                except Exception:
-                    message = '<unprintable %s object>' % type(value).__name__
+        # Callable on transaction
+        if should_ignore is None and hasattr(transaction, '_ignore_errors'):
+            should_ignore = transaction._ignore_errors(exc, value, tb)
+            if should_ignore:
+                return
+
+        # List of class names
+        if should_ignore is None and ignore is not None and not callable(ignore):
+            # Do not set should_ignore to False
+            # This should cascade into default settings rule matching
+            for name in fullnames:
+                if name in ignore:
+                    return
+
+        # Default rule matching
+        if should_ignore is None:
+            should_ignore = should_ignore_error(exc_info, status_code=status_code)
+            if should_ignore:
+                return
+
+        # Check against expected rules
+        # Boolean parameter (True/False only, not None)
+        if isinstance(expected, bool):
+            is_expected = expected
+
+        # Callable parameter
+        if is_expected is None and callable(expected):
+            is_expected = expected(exc, value, tb)
+
+
+        # List of class names
+        if is_expected is None and expected is not None and not callable(expected):
+            # Do not set is_expected to False
+            # This should cascade into default settings rule matching
+            for name in fullnames:
+                if name in expected:
+                    is_expected = True
+
+        # Default rule matching
+        if is_expected is None:
+            is_expected = is_expected_error(exc_info, status_code=status_code)
 
         # Record a supportability metric if error attributes are being
         # overiden.
@@ -303,17 +320,23 @@ class TimeTrace(object):
             transaction._record_supportability(
                     'Supportability/'
                     'SpanEvent/Errors/Dropped')
+
         # Add error details as agent attributes to span event.
-        self._add_agent_attribute('error.class', fullname)
-        self._add_agent_attribute('error.message', message)
-        return fullname, message, tb
+        self._add_agent_attribute("error.class", fullname)
+        self._add_agent_attribute("error.message", message)
+        self._add_agent_attribute("error.expected", is_expected)
 
-    def record_exception(self, exc_info=None,
-                         params={}, ignore_errors=[]):
+        return fullname, message, tb, is_expected
 
-        recorded = self._observe_exception(exc_info, ignore_errors)
+    def notice_error(self, error=None, attributes={}, expected=None, ignore=None, status_code=None):
+        recorded = self._observe_exception(
+                        error, 
+                        ignore=ignore, 
+                        expected=expected, 
+                        status_code=status_code,
+                    )
         if recorded:
-            fullname, message, tb = recorded
+            fullname, message, tb, is_expected = recorded
             transaction = self.transaction
             settings = transaction and transaction.settings
 
@@ -322,12 +345,12 @@ class TimeTrace(object):
             custom_params = {}
 
             if settings.high_security:
-                if params:
+                if attributes:
                     _logger.debug('Cannot add custom parameters in '
                             'High Security Mode.')
             else:
                 try:
-                    for k, v in params.items():
+                    for k, v in attributes.items():
                         name, val = process_user_attribute(k, v)
                         if name:
                             custom_params[name] = val
@@ -338,7 +361,17 @@ class TimeTrace(object):
                     custom_params = {}
 
             transaction._create_error_node(
-                    settings, fullname, message, custom_params, self.guid, tb)
+                    settings, fullname, message, is_expected, custom_params, self.guid, tb)
+
+
+    def record_exception(self, exc_info=None, params={}, ignore_errors=[]):
+        # Deprecation Warning
+        warnings.warn((
+            'The record_exception function is deprecated. Please use the '
+            'new api named notice_error instead.'
+        ), DeprecationWarning)
+
+        self.notice_error(error=exc_info, attributes=params, ignore=ignore_errors)
 
     def _add_agent_attribute(self, key, value):
         self.agent_attributes[key] = value
@@ -543,12 +576,32 @@ def get_linking_metadata():
 
 def record_exception(exc=None, value=None, tb=None, params={},
         ignore_errors=[], application=None):
+        # Deprecation Warning
+        warnings.warn((
+            'The record_exception function is deprecated. Please use the '
+            'new api named notice_error instead.'
+        ), DeprecationWarning)
+
+        notice_error(error=(exc, value, tb), attributes=params, ignore=ignore_errors, application=application)
+
+
+def notice_error(error=None, attributes={}, expected=None, ignore=None, status_code=None, application=None):
     if application is None:
         trace = current_trace()
         if trace:
-            trace.record_exception((exc, value, tb), params,
-                    ignore_errors)
+            trace.notice_error(
+                error=error,
+                attributes=attributes,
+                expected=expected,
+                ignore=ignore,
+                status_code=status_code,
+            )
     else:
         if application.enabled:
-            application.record_exception(exc, value, tb, params,
-                    ignore_errors)
+            application.notice_error(
+                error=error,
+                attributes=attributes,
+                expected=expected,
+                ignore=ignore,
+                status_code=status_code,
+            )
